@@ -30,6 +30,7 @@
 #include <knotifydialog.h>
 #include <kpassivepopup.h>
 #include <tdepopupmenu.h>
+#include <khelpmenu.h>
 
 // other TQt headers:
 #include <tqcursor.h>
@@ -219,17 +220,11 @@ void kpowersave::initMenu() {
 
 	HELP_SEPARATOR_MENU_ID = contextMenu()->insertSeparator();
 
-	help_menu = new TQPopupMenu(this, i18n("&Help").utf8());
-
-	help_menu->insertItem( SmallIcon("help", TQIconSet::Automatic), i18n("&KPowersave Handbook"),
-			       this, TQT_SLOT(slotHelp()));
-	help_menu->insertSeparator();
-	help_menu->insertItem( i18n("&Report a bug ..."), this, TQT_SLOT(slotReportBug()));
-	help_menu->insertItem( SmallIcon("kpowersave", TQIconSet::Automatic),
-			       i18n("&About KPowersave"), this, TQT_SLOT(slotAbout()));
-
-	HELP_MENU = contextMenu()->insertItem(SmallIcon("help", TQIconSet::Automatic),
-							i18n("&Help"), help_menu);
+	// Create help submenu
+	KHelpMenu *m_help = new KHelpMenu(this, TDEGlobal::instance()->aboutData(), false, actionCollection());
+	TDEPopupMenu *help = m_help->menu();
+	help->connectItem(KHelpMenu::menuHelpContents, this, TQT_SLOT(slotHelpContents()));
+	this->contextMenu()->insertItem(SmallIcon("help"), KStdGuiItem::help().text(), help);
 
 	connect(this, TQT_SIGNAL(quitSelected()), this, TQT_SLOT(_quit()));
 
@@ -556,34 +551,6 @@ void kpowersave::slotAbout()
         a.exec();
 }
 
-/*!
- * \b TQT_SLOT to open the website to report bugs
- */
-void kpowersave::slotReportBug()
-{
-#ifdef DISTRO_IS_SUSE
- #ifdef DISTRO_IS_SLES_SLED
-	kapp->invokeBrowser("https://bugzilla.novell.com/");
- #else
-	kapp->invokeBrowser("http://en.opensuse.org/Submitting_Bug_Reports");
- #endif
-#else
- #ifdef DISTRO_IS_ALTLINUX
-	kapp->invokeBrowser("http://bugzilla.altlinux.org/");
- #else
-  #ifdef DISTRO_IS_UBUNTU
-	kapp->invokeBrowser("https://launchpad.net/distros/ubuntu/+bugs");
-  #else
-   #ifdef DISTRO_IS_PARDUS
-	kapp->invokeBrowser("http://bugs.pardus.org.tr/");
-   #else
-	kapp->invokeBrowser("http://sourceforge.net/tracker/?group_id=124576&atid=700009");
-   #endif
-  #endif
- #endif
-#endif
-}
-
 /*!
  * \b TQT_SLOT to set the icon background on/off if battery is in critical, low or warning-state. Within
  * this function we set \ref icon_state_changed to true and call \ref redrawPixmap() to redraw the
@@ -599,6 +566,7 @@ void kpowersave::do_setIconBG(){
 
 	kdDebugFuncOut(trace);
 }
+
 /*!
  * \b TQT_SLOT to enable/disable the autosuspend.
  */
